@@ -646,8 +646,10 @@ SELECTED_OUTPUT
         permeate_moles = 0
         for index, row in enumerate(input_file):
             if 'DATABASE' in row:
-                row = row.replace('DATABASE ','')
-                self.parameters['database_selection'] = os.path.basename(fr'{row}').replace('.dat', '')
+                row = row.replace('DATABASE ','').split('/')
+                if '\\' in row[0]:
+                    row = row[0].split('\\')
+                self.parameters['database_selection'] = row[-1].split('.')[0]
             elif re.search(r'(^[A-Z][a-z \(]?[\s\d])', row):
                 element = re.search(r'(^[A-Z][a-z]?)', row).group()
                 conc = re.search(r'(?<!\()([\d\.]+)', row).group(1)
@@ -691,7 +693,8 @@ SELECTED_OUTPUT
                     self.parameters['simulation_perspective'] = 'all_time'
                     
         # open the respective database
-        self.parameters['database_path'] = os.path.join(self.parameters['root_path'], 'databases', self.parameters['database_selection']+'.dat')
+        self.parameters['database_path'] = os.path.join(
+            self.parameters['root_path'], 'databases', self.parameters['database_selection']+'.dat')
         self._define_database()
         self._described_minerals()
                     
@@ -1204,4 +1207,4 @@ SELECTED_OUTPUT
     def test(self):
         self.reactive_transport(simulation_time = 200)
         self.feed_geochemistry(water_selection = 'red_sea')
-        self.execute(simulation_name = f'rosspy_test_{self.parameters["os"]}')
\ No newline at end of file
+        self.execute(simulation_name = f'rosspy_test_{self.parameters["os"]}')
